[]Trait stats::prelude::Counter

pub trait Counter {
    fn increment_value(&self, value: i64);
}

Counter is the simplest type of aggregated stat, it behaves as a single number that can be incremented.

Required methods

fn increment_value(&self, value: i64)

Increments the counter by the given amount.

Loading content...

Implementations on Foreign Types

impl<T> Counter for Box<T> where
    T: Counter + ?Sized

Loading content...

Implementors

Loading content...