pub trait DynamicCounter<'a, T> {
// Required method
fn increment_value(&'a self, value: i64, args: T);
}Expand description
Similar to the Counter trait, but accepts the args parameter for accessing dynamic counters created at runtime.
Required Methods
Sourcefn increment_value(&'a self, value: i64, args: T)
fn increment_value(&'a self, value: i64, args: T)
Dynamic version of Counter::increment_value
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".