pub trait DynamicHistogram<'a, T> {
// Required methods
fn add_value(&'a self, value: i64, args: T);
fn add_repeated_value(&'a self, value: i64, nsamples: u32, args: T);
// Provided method
fn flush(&self) { ... }
}Expand description
Similar to the Histogram trait, but accepts the args parameter for accessing dynamic histograms created at runtime.
Required Methods
Sourcefn add_repeated_value(&'a self, value: i64, nsamples: u32, args: T)
fn add_repeated_value(&'a self, value: i64, nsamples: u32, args: T)
Dynamic version of Histogram::add_repeated_value
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".