pub fn create_map() -> Arc<ThreadMap<BoxStatsManager>> ⓘExpand description
Creates the ThreadMap and registers it for periodic calls for aggregation of stats
pub fn create_map() -> Arc<ThreadMap<BoxStatsManager>> ⓘCreates the ThreadMap and registers it for periodic calls for aggregation of stats