[−][src]Struct stats::thread_local_aggregator::StatsScheduledErrorPreview
This error is returned to indicate that the stats scheduler was already retrieved before and potentially is already running, but might be retrieved again from this error