[−]Trait stats::prelude::DynamicCounter
Similar to the Counter trait, but accepts the args parameter for accessing dynamic counters created at runtime.
Required methods
fn increment_value(&'a self, value: i64, args: T)
Dynamic version of Counter::increment_value