pub struct OnlineStats { /* private fields */ }Expand description
Online state for computing mean, variance and standard deviation.
Optimized memory layout for better cache performance:
- Grouped related fields together in hot, warm and cold paths.
Implementations
Sourceimpl OnlineStats
impl OnlineStats
Sourcepub fn new() -> OnlineStats
pub fn new() -> OnlineStats
Create initial state.
Population size, variance and mean are set to 0.
Sourcepub fn from_slice<T: ToPrimitive>(samples: &[T]) -> OnlineStats
pub fn from_slice<T: ToPrimitive>(samples: &[T]) -> OnlineStats
Initializes OnlineStats from a sample.
Sourcepub const fn variance(&self) -> f64
pub const fn variance(&self) -> f64
Return the current population variance (using N denominator, not N-1).
Sourcepub fn harmonic_mean(&self) -> f64
pub fn harmonic_mean(&self) -> f64
Return the current harmonic mean.
Sourcepub fn geometric_mean(&self) -> f64
pub fn geometric_mean(&self) -> f64
Return the current geometric mean.
Sourcepub const fn n_counts(&self) -> (u64, u64, u64)
pub const fn n_counts(&self) -> (u64, u64, u64)
Return the number of negative, zero and positive counts.
Returns a tuple (negative_count, zero_count, positive_count) where:
negative_count: number of values with negative sign bit (including -0.0)zero_count: number of values equal to +0.0positive_count: number of values greater than 0
Note: -0.0 and +0.0 are distinguished by their sign bit and counted separately.
Example
use stats::OnlineStats;
let mut stats = OnlineStats::new();
stats.extend(vec![-2, -1, 0, 0, 1, 2, 3]);
let (neg, zero, pos) = stats.n_counts();
assert_eq!(neg, 2); // -2, -1
assert_eq!(zero, 2); // 0, 0
assert_eq!(pos, 3); // 1, 2, 3Sourcepub fn add<T: ToPrimitive>(&mut self, sample: &T)
pub fn add<T: ToPrimitive>(&mut self, sample: &T)
Add a new sample.
NaN values are silently skipped to prevent corrupting the statistics.
Sourcepub fn add_f64(&mut self, sample: f64)
pub fn add_f64(&mut self, sample: f64)
Add a new f64 sample.
Skipping the ToPrimitive conversion.
NaN values are silently skipped to prevent corrupting the statistics.