[−][src]Function stats::thread_local_aggregator::create_map
pub fn create_map() -> Arc<ThreadMap<BoxStatsManager>>
Creates the ThreadMap and registers it for periodic calls for aggregation of stats
pub fn create_map() -> Arc<ThreadMap<BoxStatsManager>>
Creates the ThreadMap and registers it for periodic calls for aggregation of stats